const E2BIG = Int32(7)
const EACCES = Int32(13)
const EADDRINUSE = Int32(100)
const EADDRNOTAVAIL = Int32(101)
const EAFNOSUPPORT = Int32(102)
const EAGAIN = Int32(11)
const EALREADY = Int32(103)
const EBADF = Int32(9)
const EBADMSG = Int32(104)
const EBUSY = Int32(16)
const ECANCELED = Int32(105)
const ECHILD = Int32(10)
const ECONNABORTED = Int32(106)
const ECONNREFUSED = Int32(107)
const ECONNRESET = Int32(108)
const EDEADLK = Int32(36)
const EDESTADDRREQ = Int32(109)
const EDOM = Int32(33)
const EEXIST = Int32(17)
const EFAULT = Int32(14)
const EFBIG = Int32(27)
const EHOSTUNREACH = Int32(110)
const EIDRM = Int32(111)
const EILSEQ = Int32(42)
const EINPROGRESS = Int32(112)
const EINTR = Int32(4)
const EINVAL = Int32(22)
const EIO = Int32(5)
const EISCONN = Int32(113)
const EISDIR = Int32(21)
const ELOOP = Int32(114)
const EMFILE = Int32(24)
const EMLINK = Int32(31)
const EMSGSIZE = Int32(115)
const ENAMETOOLONG = Int32(38)
const ENETDOWN = Int32(116)
const ENETRESET = Int32(117)
const ENETUNREACH = Int32(118)
const ENFILE = Int32(23)
const ENOBUFS = Int32(119)
const ENODATA = Int32(120)
const ENODEV = Int32(19)
const ENOENT = Int32(2)
const ENOEXEC = Int32(8)
const ENOLCK = Int32(39)
const ENOLINK = Int32(121)
const ENOMEM = Int32(12)
const ENOMSG = Int32(122)
const ENOPROTOOPT = Int32(123)
const ENOSPC = Int32(28)
const ENOSR = Int32(124)
const ENOSTR = Int32(125)
const ENOSYS = Int32(40)
const ENOTCONN = Int32(126)
const ENOTDIR = Int32(20)
const ENOTEMPTY = Int32(41)
const ENOTRECOVERABLE = Int32(127)
const ENOTSOCK = Int32(128)
const ENOTSUP = Int32(129)
const ENOTTY = Int32(25)
const ENXIO = Int32(6)
const EOPNOTSUPP = Int32(130)
const EOVERFLOW = Int32(132)
const EOWNERDEAD = Int32(133)
const EPERM = Int32(1)
const EPIPE = Int32(32)
const EPROTO = Int32(134)
const EPROTONOSUPPORT = Int32(135)
const EPROTOTYPE = Int32(136)
const ERANGE = Int32(34)
const EROFS = Int32(30)
const ESPIPE = Int32(29)
const ESRCH = Int32(3)
const ETIME = Int32(137)
const ETIMEDOUT = Int32(138)
const ETXTBSY = Int32(139)
const EWOULDBLOCK = Int32(140)
const EXDEV = Int32(18)
